[qet] [4626] Titleblock properties rename properties %loc to %locmach

[ Thread Index | Date Index | More lists.tuxfamily.org/qet Archives ]


Revision: 4626
Author:   scorpio810
Date:     2016-08-12 13:32:56 +0200 (Fri, 12 Aug 2016)
Log Message:
-----------
Titleblock properties rename properties %loc to %locmach

Modified Paths:
--------------
    trunk/sources/bordertitleblock.cpp
    trunk/sources/bordertitleblock.h
    trunk/sources/diagramfoliolist.cpp
    trunk/sources/titleblock/templatecellwidget.cpp
    trunk/sources/titleblockproperties.cpp
    trunk/sources/titleblockproperties.h
    trunk/sources/ui/titleblockpropertieswidget.cpp
    trunk/sources/ui/titleblockpropertieswidget.ui

Modified: trunk/sources/bordertitleblock.cpp
===================================================================
--- trunk/sources/bordertitleblock.cpp	2016-08-12 10:45:18 UTC (rev 4625)
+++ trunk/sources/bordertitleblock.cpp	2016-08-12 11:32:56 UTC (rev 4626)
@@ -241,7 +241,7 @@
 	ip.title = title();
 	ip.filename = fileName();
 	ip.machine = machine();
-	ip.loc = loc();
+	ip.locmach = locmach();
 	ip.indexrev = indexrev();
 	ip.version = version();
 	ip.folio = folio();
@@ -264,7 +264,7 @@
 	setTitle(ip.title);
 	setFileName(ip.filename);
 	setMachine(ip.machine);
-	setLoc(ip.loc);
+	setLocMach(ip.locmach);
 	setIndicerev(ip.indexrev);
 	setVersion(QET::displayedVersion);
 	setFolio(ip.folio);
@@ -702,7 +702,7 @@
 	context.addValue("title",       btb_title_);
 	context.addValue("filename",    btb_filename_);
 	context.addValue("machine",     btb_machine_);
-	context.addValue("loc",         btb_loc_);
+	context.addValue("locmach",     btb_locmach_);
 	context.addValue("indexrev",    btb_indexrev_);
 	context.addValue("version",     btb_version_);
 	context.addValue("folio",       btb_final_folio_);

Modified: trunk/sources/bordertitleblock.h
===================================================================
--- trunk/sources/diagramfoliolist.cpp	2016-08-12 10:45:18 UTC (rev 4625)
+++ trunk/sources/diagramfoliolist.cpp	2016-08-12 11:32:56 UTC (rev 4626)
@@ -94,7 +94,7 @@
 				QString::number(diagram_list[i] ->folioIndex()+1),
 				diagram_list[i] -> border_and_titleblock.folio(),
 				diagram_list[i] -> border_and_titleblock.machine(),
-				diagram_list[i] -> border_and_titleblock.loc(),
+				diagram_list[i] -> border_and_titleblock.locmach(),
 				diagram_list[i] -> border_and_titleblock.indexrev(),
 				diagram_list[i] -> border_and_titleblock.date().toString(Qt::SystemLocaleShortDate));
 	}

Modified: trunk/sources/titleblock/templatecellwidget.cpp
===================================================================
--- trunk/sources/titleblock/templatecellwidget.cpp	2016-08-12 10:45:18 UTC (rev 4625)
+++ trunk/sources/titleblock/templatecellwidget.cpp	2016-08-12 11:32:56 UTC (rev 4626)
@@ -438,7 +438,7 @@
 		"<li>%{title} : titre du folio</li>"
 		"<li>%{filename} : nom de fichier du projet</li>"
 		"<li>%{machine} : nom du groupe fonctionnel du projet</li>"
-		"<li>%{loc} : nom de la localisation dans le groupe fonctionnel du projet</li>"
+		"<li>%{locmach} : nom de la localisation dans le groupe fonctionnel du projet</li>"
 		"<li>%{indexrev} : indice de révision du folio</li>"
 		"<li>%{version} : version du logiciel</li>"
 		"<li>%{folio} : indications relatives au folio</li>"

Modified: trunk/sources/titleblockproperties.cpp
===================================================================
--- trunk/sources/titleblockproperties.cpp	2016-08-12 10:45:18 UTC (rev 4625)
+++ trunk/sources/titleblockproperties.cpp	2016-08-12 11:32:56 UTC (rev 4626)
@@ -48,7 +48,7 @@
 		ip.date == date &&\
 		ip.filename == filename &&\
 		ip.machine == machine &&\
-		ip.loc == loc &&\
+		ip.locmach == locmach &&\
 		ip.indexrev == indexrev &&\
 		ip.version == version &&\
 		ip.folio == folio &&\
@@ -78,7 +78,7 @@
 	e.setAttribute("title",    title);
 	e.setAttribute("filename", filename);
 	e.setAttribute("machine", machine);
-	e.setAttribute("loc", loc);
+	e.setAttribute("locmach", locmach);
 	e.setAttribute("indexrev",indexrev);
 	e.setAttribute("version", version);
 	e.setAttribute("folio",    folio);
@@ -108,7 +108,7 @@
 	if (e.hasAttribute("title"))       title    = e.attribute("title");
 	if (e.hasAttribute("filename"))    filename = e.attribute("filename");
 	if (e.hasAttribute("machine"))    machine   = e.attribute("machine");
-	if (e.hasAttribute("loc"))        loc       = e.attribute("loc");
+	if (e.hasAttribute("locmach"))     locmach  = e.attribute("locmach");
 	if (e.hasAttribute("indexrev"))   indexrev  = e.attribute("indexrev");
 	if (e.hasAttribute("version"))    version   = e.attribute("version");
 	if (e.hasAttribute("folio"))       folio    = e.attribute("folio");
@@ -141,7 +141,7 @@
 	settings.setValue(prefix + "author",   author);
 	settings.setValue(prefix + "filename", filename);
 	settings.setValue(prefix + "machine", machine);
-	settings.setValue(prefix + "loc", loc);
+	settings.setValue(prefix + "locmach", locmach);
 	settings.setValue(prefix + "indexrev", indexrev);
 	settings.setValue(prefix + "version", version);
 	settings.setValue(prefix + "folio",    folio);
@@ -163,7 +163,7 @@
 	author   = settings.value(prefix + "author").toString();
 	filename = settings.value(prefix + "filename").toString();
 	machine  = settings.value(prefix + "machine").toString();
-	loc      = settings.value(prefix + "loc").toString();
+	locmach  = settings.value(prefix + "locmach").toString();
 	indexrev = settings.value(prefix + "indexrev").toString();
 	version  = settings.value(prefix + "version").toString();
 	folio    = settings.value(prefix + "folio", "%id/%total").toString();

Modified: trunk/sources/titleblockproperties.h
===================================================================
--- trunk/sources/titleblockproperties.h	2016-08-12 10:45:18 UTC (rev 4625)
+++ trunk/sources/titleblockproperties.h	2016-08-12 11:32:56 UTC (rev 4626)
@@ -55,7 +55,7 @@
 	QDate date;               ///< Date (displayed by the default template)
 	QString filename;         ///< Filename (displayed by the default template)
 	QString machine;          ///< Machine (displayed by the default template)
-	QString loc;              ///< Location(displayed by the default template)
+	QString locmach;              ///< Location(displayed by the default template)
 	QString indexrev;         ///< Revision Index (displayed by the default template)
 	QString version;          ///< Version (displayed by the default template)
 	QString folio;            ///< Folio information (displayed by the default template)

Modified: trunk/sources/ui/titleblockpropertieswidget.cpp
===================================================================
--- trunk/sources/ui/titleblockpropertieswidget.cpp	2016-08-12 10:45:18 UTC (rev 4625)
+++ trunk/sources/ui/titleblockpropertieswidget.cpp	2016-08-12 11:32:56 UTC (rev 4626)
@@ -96,7 +96,7 @@
 	ui -> m_author_le -> setText (properties.author);
 	ui -> m_file_le   -> setText (properties.filename);
 	ui -> m_mach      -> setText (properties.machine);
-	ui -> m_loc       -> setText (properties.loc);
+	ui -> m_loc   -> setText (properties.locmach);
 	ui -> m_indice    -> setText (properties.indexrev);
 	ui -> m_folio_le  -> setText (properties.folio);
 	ui -> m_display_at_cb -> setCurrentIndex(properties.display_at == Qt::BottomEdge ? 0 : 1);
@@ -154,7 +154,7 @@
 	prop.author   = ui -> m_author_le -> text();
 	prop.filename = ui -> m_file_le   -> text();
 	prop.machine  = ui -> m_mach      -> text();
-	prop.loc      = ui -> m_loc       -> text();
+	prop.locmach  = ui -> m_loc   -> text();
 	prop.indexrev = ui -> m_indice    -> text();
 	prop.folio    = ui -> m_folio_le  -> text();
 	prop.display_at = ui -> m_display_at_cb -> currentIndex() == 0 ? Qt::BottomEdge : Qt::RightEdge;
@@ -195,7 +195,7 @@
 	prop.author   = ui -> m_author_le -> text();
 	prop.filename = ui -> m_file_le   -> text();
 	prop.machine  = ui -> m_mach      -> text();
-	prop.loc      = ui -> m_loc       -> text();
+	prop.locmach  = ui -> m_loc       -> text();
 	prop.indexrev = ui -> m_indice    -> text();
 	prop.folio    = "%autonum";
 	prop.display_at = ui -> m_display_at_cb -> currentIndex() == 0 ? Qt::BottomEdge : Qt::RightEdge;

Modified: trunk/sources/ui/titleblockpropertieswidget.ui
===================================================================
--- trunk/sources/ui/titleblockpropertieswidget.ui	2016-08-12 10:45:18 UTC (rev 4625)
+++ trunk/sources/ui/titleblockpropertieswidget.ui	2016-08-12 11:32:56 UTC (rev 4626)
@@ -194,7 +194,7 @@
                 <item row="8" column="3">
                  <widget class="QLineEdit" name="m_loc">
                   <property name="toolTip">
-                   <string>Disponible en tant que %loc pour les modèles de cartouches</string>
+                   <string>Disponible en tant que %locmach pour les modèles de cartouches</string>
                   </property>
                  </widget>
                 </item>


Mail converted by MHonArc 2.6.19+ http://listengine.tuxfamily.org/
--- trunk/sources/bordertitleblock.h	2016-08-12 10:45:18 UTC (rev 4625)
+++ trunk/sources/bordertitleblock.h	2016-08-12 11:32:56 UTC (rev 4626)
@@ -97,8 +97,8 @@
 	QString folio() const { return(btb_folio_); }
 	/// @return the value of the title block "Machine" field
 	QString machine() const { return(btb_machine_); }
-	/// @return the value of the title block "Folio" field
-	QString loc() const { return(btb_loc_); }
+	/// @return the value of the title block "Locmach" field
+	QString locmach() const { return(btb_locmach_); }
 	/// @return the value of the revision index block "Folio" field
 	QString indexrev() const { return(btb_indexrev_); }
 	
@@ -154,7 +154,7 @@
 	void setFolioData(int, int, QString = NULL, const DiagramContext & = DiagramContext());
 	/// @param author the new value of the "File" field
 	void setMachine(const QString &machine) { btb_machine_ = machine; }
-	void setLoc(const QString &loc) { btb_loc_ = loc; }
+	void setLocMach(const QString &locmach) { btb_locmach_ = locmach; }
 	void setIndicerev(const QString &indexrev){ btb_indexrev_ = indexrev; }
 	void setFileName(const QString &filename) { btb_filename_ = filename; }
 	/// @param author the new value of the "Version" field
@@ -236,7 +236,7 @@
 		QString btb_title_;
 		QString btb_folio_;
 		QString btb_machine_;
-		QString btb_loc_;
+		QString btb_locmach_;
 		QString btb_indexrev_;
 		QString btb_final_folio_;
 		QString btb_auto_page_num_;

Modified: trunk/sources/diagramfoliolist.cpp
===================================================================